@@ -74,6 +74,8 @@ bool HTTPFileSystem::handle_required_config(const std::string &name_from_config,
 }
 
 bool HTTPFileSystem::Config(XrdSysLogger *lp, const char *configfn) {
+	m_remote_flavor = "auto";
+
 	XrdOucEnv myEnv;
 	XrdOucGatherConf httpserver_conf("httpserver.", &m_log);
 	int result;
@@ -108,6 +110,8 @@ bool HTTPFileSystem::Config(XrdSysLogger *lp, const char *configfn) {
 									http_host_url) ||
 			!handle_required_config(attribute, "httpserver.url_base", value,
 									m_url_base) ||
+			!handle_required_config(attribute, "httpserver.remote_flavor",
+									value, m_remote_flavor) ||
 			!handle_required_config(attribute, "httpserver.storage_prefix",
 									value, m_storage_prefix) ||
 			!handle_required_config(attribute, "httpserver.token_file", value,
@@ -127,6 +131,12 @@ bool HTTPFileSystem::Config(XrdSysLogger *lp, const char *configfn) {
 								 "httpserver.url_base are required");
 			return false;
 		}
+		if (m_remote_flavor != "http" && m_remote_flavor != "webdav" &&
+			m_remote_flavor != "auto") {
+			m_log.Emsg("Config", "Invalid httpserver.remote_flavor specified; "
+								 "must be one of: 'http', 'webdav', or 'auto'");
+			return false;
+		}
 	}
 
 	if (!token_file.empty()) {
@@ -139,7 +149,7 @@ bool HTTPFileSystem::Config(XrdSysLogger *lp, const char *configfn) {
 // Object Allocation Functions
 //
 XrdOssDF *HTTPFileSystem::newDir(const char *user) {
-	return new HTTPDirectory(m_log);
+	return new HTTPDirectory(m_log, *this);
 }
 
 XrdOssDF *HTTPFileSystem::newFile(const char *user) {
@@ -150,12 +160,13 @@ int HTTPFileSystem::Stat(const char *path, struct stat *buff, int opts,
 						 XrdOucEnv *env) {
 	std::string error;
 
-	m_log.Emsg("Stat", "Stat'ing path", path);
+	// need to forward a HEAD request to the remote server
 
 	HTTPFile httpFile(m_log, this);
 	int rv = httpFile.Open(path, 0, (mode_t)0, *env);
-	if (rv) {
+	if (rv && rv != -EISDIR) {
 		m_log.Emsg("Stat", "Failed to open path:", path);
+		return rv;
 	}
 	// Assume that HTTPFile::FStat() doesn't write to buff unless it succeeds.
 	return httpFile.Fstat(buff);
@@ -173,3 +184,31 @@ int HTTPFileSystem::Create(const char *tid, const char *path, mode_t mode,
 
 	return 0;
 }
+
+int HTTPFileSystem::Unlink(const char *path, int Opts, XrdOucEnv *env) {
+	m_log.Log(LogMask::Debug, "Unlink", "Unlinking path", path);
+	// make sure file exists
+	HTTPFile httpFile(m_log, this);
+	if (httpFile.Open(path, 0, (mode_t)0, *env) != 0) {
+		m_log.Emsg("Unlink", "Failed to open path:", path);
+		return -ENOENT;
+	}
+
+	std::string object;
+	if (parse_path(getStoragePrefix(), path, object) != 0) {
+		m_log.Emsg("Unlink", "Failed to parse path:", path);
+		return -EIO;
+	}
+	// delete the file
+	std::string hostUrl =
+		!getHTTPUrlBase().empty() ? getHTTPUrlBase() : getHTTPHostUrl();
+	m_log.Log(LogMask::Debug, "Unlink", "Object:", object.c_str());
+	m_log.Log(LogMask::Debug, "Unlink", "Host URL:", hostUrl.c_str());
+	HTTPDelete deleteCommand(hostUrl, object, m_log, &m_token);
+	if (!deleteCommand.SendRequest()) {
+		return HTTPRequest::HandleHTTPError(deleteCommand, m_log, "DELETE",
+											object.c_str());
+	}
+
+	return 0;
+}
